class ScoreCalculatorWorker
  include Sidekiq::Worker
  sidekiq_options queue: :score
  include RepositoriesProxy

  def perform(rid)
    object = learning_object_repository.find(rid)

    unless object.blank?
      weights = {"thumbnail": 40, "likes": 20, "views": 10, "description": 30}

      score = 0

      # 40 points if it has thumbnail
      score += weights[:thumbnail] unless object.thumbnail.blank?

      # 1 point per like
      likes = learning_object_repository.count_likes(object)
      score += (likes / learning_object_repository.max_likes)*weights[:likes]  unless likes < 1

      # 1 point per view
      views = learning_object_repository.count_views(object)
      score += (views / learning_object_repository.max_views)*weights[:views] unless views < 1

      # 30 points if it has description
      score += weights[:description] unless object.description.blank?

      learning_object_repository.update_property(object, 'score', score)
    end
  end
end
